locate_path

Function locate_path 

pub fn locate_path(
    tree: &Tree,
    source: &str,
    path: &[&str],
) -> Result<Located, String>
Locate path in the parsed tree. path is a sequence of mapping keys (the YAML form of a JSONPath); each segment names a child of the previous segment’s mapping.

On success returns either Located::Found (the path fully resolved) or Located::Missing (path resolved up to a point; new keys need to be inserted at the returned offset).