verify_file

Function verify_file 

pub fn verify_file(
    binary: &Path,
    label_root: &str,
    workload: &Path,
    sandbox: &Path,
) -> Vec<(String, Outcome)>
Verify one workload file: read it, then run it by its absolute path. The file is read relative to this process’s cwd, but the run reference is made absolute because each case is launched from a sandbox cwd.